NAME
WebService::GData::Serialize - Factory class that loads the proper serialize package
SYNOPSIS
#the code below will load WebService::GData::Serialize::XML;
#and call its encode function
my $xml= WebService::GData::Serialize->to_xml(@args);
#or
my $xml = WebService::GData::Serialize->as_xml(@args);
#or
my $xml = WebService::GData::Serialize->xml(@args);
#a json format might be added
#load behind the scene: WebService::GData::Serialize::JSON
my $json = WebService::GData::Serialize->to_json(@args);
DESCRIPTION
inherits from WebService::GData
This package is a simple helper factory class that will load a serializer package and calls its encode function. Concrete serializer class should inherit from WebService::GData::Serialize::AbstractSerializer and implement the encode function.
See also WebService::GData::Serialize::AbstractSerializer.
AUTOLOAD
__set
This function will be called when an undefined function on this package is used. It will load the corresponding serializer package. It follows the following format:
- *The function can be suffixed with to_ or as_. It will look for the serializer package name specified after the prefix.
- *The function is change into uppercase, therefore,the name can be either uppercase letters (as the real serializer package name) or lowercase letters.
- *The function must be used in a __set context. You have to specify arguments.
Parameters
Returns
- serialized_data:* Although the return value shall certainly be raw scalar data, it depends on the serializer package.
Example:
see SYNOPSYS
BUGS AND LIMITATIONS
If you do me the favor to _use_ this module and find a bug, please email me i will try to do my best to fix it (patches welcome)!
AUTHOR
shiriru <shirirulestheworld[arobas]gmail.com>
LICENSE AND COPYRIGHT
This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.